@@ -14,7 +14,7 @@
 #include "sqfs/error.h"
 #include "sqfs/block.h"
 #include "sqfs/io.h"
-#include "util/util.h"
+#include "../util.h"
 
 SQFS_INTERNAL
 int sqfs_generic_write_options(sqfs_file_t *file, const void *data,
@@ -29,9 +29,6 @@ sqfs_compressor_t *xz_compressor_create(const sqfs_compressor_config_t *cfg);
 SQFS_INTERNAL
 sqfs_compressor_t *gzip_compressor_create(const sqfs_compressor_config_t *cfg);
 
-SQFS_INTERNAL
-sqfs_compressor_t *lzo_compressor_create(const sqfs_compressor_config_t *cfg);
-
 SQFS_INTERNAL
 sqfs_compressor_t *lz4_compressor_create(const sqfs_compressor_config_t *cfg);
 
