@@ -9,7 +9,6 @@
 
 #include "config.h"
 
-#include "util/util.h"
 #include "tar.h"
 
 #include <string.h>
@@ -56,13 +55,13 @@ bool is_checksum_valid(const tar_header_t *hdr);
 
 sparse_map_t *read_sparse_map(const char *line);
 
-sparse_map_t *read_gnu_old_sparse(int fd, tar_header_t *hdr);
+sparse_map_t *read_gnu_old_sparse(FILE *fp, tar_header_t *hdr);
 
 void free_sparse_list(sparse_map_t *sparse);
 
 void free_xattr_list(tar_xattr_t *list);
 
-void base64_decode(sqfs_u8 *out, const char *in);
+size_t base64_decode(sqfs_u8 *out, const char *in, size_t len);
 
 void urldecode(char *str);
 
