@@ -7,6 +7,7 @@
 #include "config.h"
 
 #include "fstree.h"
+#include "internal.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -29,7 +30,8 @@ int main(void)
 	fstree_cleanup(&fs);
 
 	assert(fstree_init(&fs, NULL) == 0);
-	assert(fs.defaults.st_mtime == 0);
+	assert(fs.defaults.st_mtime == 0 ||
+	       fs.defaults.st_mtime == get_source_date_epoch());
 	assert(fs.defaults.st_uid == 0);
 	assert(fs.defaults.st_gid == 0);
 	assert(fs.defaults.st_mode == (S_IFDIR | 0755));
