@@ -19,7 +19,6 @@ int main(void)
 	fstree_t fs;
 
 	memset(&fs, 0, sizeof(fs));
-	fs.block_size = 512;
 
 	memset(&sb, 0, sizeof(sb));
 	sb.st_mode = S_IFREG | 0654;
@@ -33,6 +32,7 @@ int main(void)
 	assert(node->gid == sb.st_gid);
 	assert(node->mode == sb.st_mode);
 	assert(node->parent == NULL);
+	assert(node->link_count == 1);
 	assert((char *)node->name >= (char *)node->payload);
 	assert(node->data.file.input_file >= (char *)node->payload);
 	assert(node->data.file.input_file >= node->name + 8);
