@@ -6,14 +6,11 @@
  */
 #include "config.h"
 
-#include "util/util.h"
 #include "tar.h"
 
-#include <unistd.h>
 #include <assert.h>
 #include <stdlib.h>
 #include <string.h>
-#include <fcntl.h>
 #include <stdio.h>
 
 #define STR(x) #x
@@ -21,28 +18,28 @@
 
 #define TEST_PATH STRVALUE(TESTPATH)
 
-static int open_read(const char *path)
+static FILE *open_read(const char *path)
 {
-	int fd = open(path, O_RDONLY);
+	FILE *fp = fopen(path, "rb");
 
-	if (fd < 0) {
+	if (fp == NULL) {
 		perror(path);
 		exit(EXIT_FAILURE);
 	}
 
-	return fd;
+	return fp;
 }
 
 int main(void)
 {
 	tar_header_decoded_t hdr;
 	char buffer[6];
-	int fd;
+	FILE *fp;
 
 	assert(chdir(TEST_PATH) == 0);
 
-	fd = open_read("xattr/xattr-libarchive.tar");
-	assert(read_header(fd, &hdr) == 0);
+	fp = open_read("xattr/xattr-libarchive.tar");
+	assert(read_header(fp, &hdr) == 0);
 	assert(hdr.sb.st_mode == (S_IFREG | 0644));
 	assert(hdr.sb.st_uid == 01750);
 	assert(hdr.sb.st_gid == 01750);
@@ -51,16 +48,17 @@ int main(void)
 	assert(hdr.mtime == 1543094477);
 	assert(strcmp(hdr.name, "input.txt") == 0);
 	assert(!hdr.unknown_record);
-	assert(read_retry("data0", fd, buffer, 5) == 0);
+	assert(read_retry("data0", fp, buffer, 5) == 0);
 	buffer[5] = '\0';
 	assert(strcmp(buffer, "test\n") == 0);
 
 	assert(hdr.xattr != NULL);
 	assert(strcmp(hdr.xattr->key, "user.mime_type") == 0);
-	assert(strcmp(hdr.xattr->value, "text/plain") == 0);
+	assert(strcmp((const char *)hdr.xattr->value, "text/plain") == 0);
+	assert(hdr.xattr->value_len == 10);
 	assert(hdr.xattr->next == NULL);
 
 	clear_header(&hdr);
-	close(fd);
+	fclose(fp);
 	return EXIT_SUCCESS;
 }
