@@ -10,19 +10,20 @@
 #include "config.h"
 #include "common.h"
 #include "fstree.h"
-#include "util/util.h"
 
+#ifdef _WIN32
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+#endif
 #ifdef HAVE_SYS_XATTR_H
 #include <sys/xattr.h>
 #endif
 #include <string.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <getopt.h>
 #include <assert.h>
 #include <ctype.h>
 #include <errno.h>
-#include <fcntl.h>
 #include <stdio.h>
 
 enum UNPACK_FLAGS {
